group_cipher_get_user_data

Function group_cipher_get_user_data 

pub unsafe extern "C" fn group_cipher_get_user_data(
    cipher: *mut group_cipher,
) -> *mut c_void
Get the optional user data pointer for the group cipher.

This is to give callback functions a way of accessing app specific context information for this cipher.