group_cipher_set_user_data

Function group_cipher_set_user_data 

pub unsafe extern "C" fn group_cipher_set_user_data(
    cipher: *mut group_cipher,
    user_data: *mut c_void,
)
Set the optional user data pointer for the group cipher.

This is to give callback functions a way of accessing app specific context information for this cipher.