group_session_builder_create

Function group_session_builder_create 

pub unsafe extern "C" fn group_session_builder_create(
    builder: *mut *mut group_session_builder,
    store: *mut signal_protocol_store_context,
    global_context: *mut signal_context,
) -> c_int
Constructs a group session builder.

The store and global contexts must remain valid for the lifetime of the session builder.

When finished, free the returned instance by calling group_session_builder_free().

@param builder set to a freshly allocated group session builder instance @param store the signal_protocol_store_context to store all state information in @param global_context the global library context @return 0 on success, or negative on failure