pub unsafe extern "C" fn session_cipher_get_user_data(
cipher: *mut session_cipher,
) -> *mut c_voidExpand description
Get the optional user data pointer for the session cipher.
This is to give callback functions a way of accessing app specific context information for this cipher.