pub unsafe extern "C" fn session_cipher_set_user_data(
cipher: *mut session_cipher,
user_data: *mut c_void,
)Expand description
Set the optional user data pointer for the session cipher.
This is to give callback functions a way of accessing app specific context information for this cipher.