pub unsafe extern "C" fn session_cipher_encrypt(
cipher: *mut session_cipher,
padded_message: *const u8,
padded_message_len: usize,
encrypted_message: *mut *mut ciphertext_message,
) -> c_intExpand description
Encrypt a message.
@param padded_message The plaintext message bytes, optionally padded to a constant multiple. @param padded_message_len The length of the data pointed to by padded_message @param encrypted_message Set to a ciphertext message encrypted to the recipient+device tuple.
@return SG_SUCCESS on success, negative on error