pub unsafe extern "C" fn session_cipher_get_session_version(
cipher: *mut session_cipher,
version: *mut u32,
) -> c_intExpand description
Gets the version of the session associated with this session cipher.
@param version Set to the value of the session version
@retval SG_SUCCESS Success @retval SG_ERR_NO_SESSION if no session could be found